Test Effects

### Here are demos of all combination effects:

Click for Visual.appear demo
Click for Visual.fade demo
Click for Visual.puff demo
Click for Visual.blindDown demo
Click for Visual.blindUp demo
Click for Visual.switchOff demo
Click for Visual.slideDown demo
Click for Visual.slideUp demo
Click for Visual.dropOut demo
Click for Visual.shake demo
Click for Visual.pulsate demo
Click for Visual.squish demo
Click for Visual.fold demo
Click for Visual.grow demo
Click for Visual.shrink demo
Click for Visual.Highlight demo

### Here are all demos on one single element:

Click to see the selected effect
in slow-motion

### Links to other samples:

- Big slide effects
- Slide effects
- Blind effects
- Blind/Slide effects
- Fade/Appear effects

- Onload effects
- Scroll effects
- Grow/Shrink effects
- Queue effects
- Queue limit effects